{ 
  -= Module MENUBAR =-

  Project: Batalha Naval
  Programmed by: Marcelo Silveira
  E-mail: flamar98@hotmail.com
  Date: October 2018
  License: GNU-GPL, v. 3.x

  Constants and Variables
  max_menu_item - Maximum number of menu options.
  menu_scr_width - Screen width.
  menu_scr_height - Screen height.
  menu_opts - Store the menu options strings.
  menu_items - Number of menu items.
  menu_bg_color - Menu background color.
  menu_color - Menu border and text color.
  menu_header_color - Header backgorund color.
  menu_header_txt_color - Header text color.
  menu_title - The menu title.
  menu_x_padding - Menu padding in Y.
  menu_y_padding - Menu padding in Y.
  menu_i - Current menu option.

  Procedures and functions
  clear_menu - Clear menu data.
  get_menu_dimensions - Get the menu box dimensions.
  highlight_item - Highlight the current item.
  clear_item - Clear current item highlight.
  draw_final_menu - Draw whole menu on screen.
  menubar_set_title - Set menu title.
  menubar_start - Show and control menu on screen.
  menubar_set_padding - Set menu padding (internal margin).
  menubar_set_colors - Set menu colors.
  menubar_get_option - Return selected option.
  menubar_init - Call all necessary routines at the beginning.
}

type menu_str = string[20];

const max_menu_item : byte = 5;
      menu_scr_width : integer = 512;
      menu_scr_height : integer = 212;

var menu_opt : array[1..5] of menu_str;
    menu_items : integer;
    menu_bg_color, menu_color, menu_header_color, menu_header_txt_color : integer;
    menu_title : menu_str;
    menu_x_padding, menu_y_padding, menu_i : byte;


{ Private }

procedure clear_menu;
var i : integer;
begin
  for i:=1 to 10 do
    menu_opt[i] := '';
  menu_items := 0;
end;

procedure get_menu_dimensions(var xi, yi, xf, yf : integer);
var width, height, num_char : integer;
begin
  num_char := 15;
  width := (num_char)*8 + menu_x_padding*2;
  height := (menu_items+1)*10 + menu_y_padding*2;

  xi := (menu_scr_width - width) div 2;
  yi := (menu_scr_height - height) div 2;
  xf := xi + width - 1;
  yf := yi + height - 1;
end;

procedure highlight_item(xi, yi, xf, yf : integer);
begin
  line_bf(xi+menu_x_padding, yi+10*menu_i+menu_y_padding-1, xf-menu_x_padding,
  yi+10*menu_i+menu_y_padding+8, menu_color, 0);

  Color(menu_bg_color, menu_color, 0);
  GraphicPrint(menu_opt[menu_i], xi+menu_x_padding, yi+10*menu_i+menu_y_padding, 0, 0);
end;

procedure clear_item(xi, yi, xf, yf : integer);
begin
  line_bf(xi+menu_x_padding, yi+10*menu_i+menu_y_padding-1, xf-menu_x_padding,
  yi+10*menu_i+menu_y_padding+8, menu_bg_color, 0);

  Color(menu_color, menu_bg_color, 0);
  GraphicPrint(menu_opt[menu_i], xi+menu_x_padding, yi+10*menu_i+menu_y_padding, 0, 0);
end;

procedure draw_final_menu(xi, yi, xf, yf : integer);
var i : integer;
begin
  line_bf(xi, yi, xf, yf, menu_bg_color, 0);
  line_b(xi, yi, xf, yf, menu_color, 0);
  line_bf(xi+1, yi+1, xf-1, yi+10, menu_header_color, 0);

  Color(menu_header_txt_color, menu_header_color, 0);
  GraphicPrint(menu_title, xi+menu_x_padding, yi+2, 0, 0);

  for i:=1 to menu_items do
  begin
    Color(menu_color, menu_bg_color, 0);
    GraphicPrint(menu_opt[i], xi+menu_x_padding, yi+10*i+menu_y_padding, 0, 0);
  end;
end;


{ Public }

procedure menubar_set_title(t : menu_str);
begin
  menu_title := t;
end;

procedure menubar_add(opt : menu_str);
begin
  if (menu_items < max_menu_item) then
  begin
    menu_items := menu_items + 1;
    menu_opt[menu_items] := opt;
  end;
end;

procedure menubar_start;
var xi, yi, xf, yf : integer;
    c : char;
begin
  menu_i := 1;
  get_menu_dimensions(xi, yi, xf, yf);
  draw_final_menu(xi, yi, xf, yf);
  c := chr(0);

  while ord(c)<>13 do
  begin
    highlight_item(xi, yi, xf, yf);
    read(KBD,c);
    clear_item(xi, yi, xf, yf);
    case ord(c) of
      28,31 : begin
                menu_i := menu_i + 1;
                if (menu_i > menu_items) then menu_i := 1;
              end;
      29,30 : begin
                menu_i := menu_i - 1;
                if (menu_i < 1) then menu_i := menu_items;
              end;      
    end; 
  end;

end;

procedure menubar_set_padding(px, py : byte);
begin
  menu_x_padding := px;
  menu_y_padding := py;
end;

procedure menubar_set_colors(bg, c, hc, htc : integer);
begin
  menu_bg_color := bg;
  menu_color := c;
  menu_header_color := hc;
  menu_header_txt_color := htc;
end;

function menubar_get_option : byte;
begin
  menubar_get_option := menu_i;
end;

procedure menubar_init;
begin
  clear_menu;
  menubar_set_colors(5, 15, 14, 1);
  menubar_set_padding(5, 5);
end;
